@@ -1,13 +1,12 @@
 import json
 
 from django.template.defaultfilters import pluralize
-
 from wagtailstreamforms.hooks import register
 from wagtailstreamforms.models import FormSubmissionFile
 from wagtailstreamforms.serializers import FormSubmissionSerializer
 
 
-@register('process_form_submission')
+@register("process_form_submission")
 def save_form_submission_data(instance, form):
     """ saves the form submission data """
 
@@ -17,19 +16,17 @@ def save_form_submission_data(instance, form):
     # change the submission data to a count of the files
     for field in form.files.keys():
         count = len(form.files.getlist(field))
-        submission_data[field] = '{} file{}'.format(count, pluralize(count))
+        submission_data[field] = "{} file{}".format(count, pluralize(count))
 
     # save the submission data
     submission = instance.get_submission_class().objects.create(
         form_data=json.dumps(submission_data, cls=FormSubmissionSerializer),
-        form=instance
+        form=instance,
     )
 
     # save the form files
     for field in form.files:
         for file in form.files.getlist(field):
             FormSubmissionFile.objects.create(
-                submission=submission,
-                field=field,
-                file=file
+                submission=submission, field=field, file=file
             )
